@@ -1,5 +1,5 @@
 package FIAS::SQL;
-$FIAS::SQL::VERSION = '0.07';
+$FIAS::SQL::VERSION = '0.08';
 # ABSTRACT: Модуль для минимальной работы с данными из базы ФИАC https://fias.nalog.ru/FiasInfo.aspx
 
 use strict;
@@ -454,23 +454,24 @@ sub get_actual_base_version {
 
     return $firstline;
 }
+
+sub clone_base_structure {
+    my ( $self, $destination_object ) = @_;
+
+    # Забираем список таблиц из ФИАС
+    my @fias_tables = grep { $_ !~ /\_$/} @{ $self->show_tables() };
+    # Создаём таблицы в тестовой базе
+    for my $table_name ( @fias_tables ) {
+        my $cr_statement = $self->{dbh}->selectcol_arrayref( "SHOW CREATE TABLE $table_name", { Columns => [2] } )->[0];
+        $destination_object->{dbh}->do( $cr_statement );
+    }
+}
+
 sub show_tables {
     my ( $self ) = @_;
 
     return $self->{dbh}->selectcol_arrayref("show tables");
 }
-sub show_create_table_for_table {
-    my ( $self, $table_name ) = @_;
-
-    return $self->{dbh}->selectcol_arrayref( "SHOW CREATE TABLE $table_name", { Columns => [2] } )->[0];
-}
-
-sub create_tables {
-    my ( $self, @create_table_array ) = @_;
-
-    $self->{dbh}->do( $_ )
-        for @create_table_array;
-}
 
 sub _check_record_actuality {
     my ( $record ) = @_;
@@ -641,7 +642,7 @@ FIAS::SQL - Модуль для минимальной работы с данн
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
     # Создание объекта, подключение к базе
     my  $fias = FIAS::SQL->new(
@@ -925,15 +926,13 @@ version 0.07
 =item B<get_database_version>
     Получение версии актуальной базы
 
+=item B<clone_base_structure>
+    создаём таблицы в базе
+    $destination_object -- база назначения
+
 =item B<show_tables>
     Список таблиц базы
 
-=item B<show_create_table_for_table>
-    CREATE TABLE для таблицы
-
-=item B<create_tables>
-    создаём таблицы в базе
-
 =item B<_check_record_actuality>
     Проверка записи из DBF на актуальность
 
